//Java-imports
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * <strong>Program:</strong>      BildeBok<br>
 * <strong>File:</strong>         BildeBokFrame.java<br>
 * <strong>Description:</strong>  Main-klassen som starter opp programmet, og setter opp GUI<br>
 * <strong>Author:</strong>       Kenneth Stigen - kenneths@frodo.hiof.no<br>
 * <strong>Environment:</strong>  Windows - jdk 1.3.1<br>
 * <strong>Notes:</strong>        Dette er en del av prosjektet i grafisk databehandling V2002<br>
 *
 * @author Kenneth Stigen (mailto: kenneths@frodo.hiof.no, web: http://frodo.hiof.no/~kenneths)
 * @version Version 1.0
 */
public class BildeBokFrame extends JFrame implements ActionListener {
   
   //Variabel for  registrere antall ganger bruker har trykket turnpage
   private int antPress = 0;
   
   //Debug variabel
   private boolean debugOn = false;
   
   //Container
   private Container c;
   
   //Variabler for  bestemme rotasjon som flge av musebevegelser
   //og for  bestemme om musen er i bevegelse eller ikke.
   private float rotx=0.0f;
   private float rotz=0.0f;
   private float lastx=0.0f;
   private float lastz=0.0f;
   private boolean m_is_moving=false;
   
   //Variabler for menylinjen
   private JMenuBar menyBar;
   private JMenu fil;
   private JMenu hjelp;
   private JMenuItem help;
   private JMenuItem exit;
   private JMenuItem about;
   
   //Gl-Canvas
   private BildeBokCanvas canv;
   
   //musehandler
   private MouseHandler mHandler;
   
   //Information variables
   private JPanel infoPanel;
   private JLabel infoLabel, infoLabel2, infoLabel3;
   private JButton anim, play, reset, turn;
   private Thread t, t2;
   private String heading = "Bildebok - Kenneth Stigen";
   
   /**
    * Constructor
    *
    * Kaller standard metoder for  sette i gang en frame.
    */
   public BildeBokFrame(){
      super("Bildebok - Kenneth Stigen");
      setSize(800,600);
      setupGUI();
      show();
   }
   
   
   /**
    * main
    * @param args Argumentene som er gitt inn nr en kjrer programmet
    *
    * Setter i gang showet..
    */
   public static void main(String args[]){
      BildeBokFrame myBook = new BildeBokFrame();
      myBook.addWindowListener(new CloseWindowAndExit());
   }
   
   /**
    * setupGUI
    *
    * Metode som setter opp alt det visuelle.
    */
   private void setupGUI(){
      //Klargjr musehandler
      mHandler = new MouseHandler();
      
      //Sentrerer framen til midt p skjermen
      Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
      
      Dimension frameSize = this.getSize();
      if (frameSize.height > screenSize.height)
	 frameSize.height = screenSize.height;
      if (frameSize.width > screenSize.width)
	 frameSize.width = screenSize.width;
      this.setLocation ((screenSize.width - frameSize.width)/2,(screenSize.height - frameSize.height)/2);
      
      
      //Setter opp menylinjen
      menyBar = new JMenuBar();
      setJMenuBar(menyBar);
      
      fil = new JMenu("File");
      hjelp = new JMenu("Help");
      
      menyBar.add(fil);
      menyBar.add(hjelp);
      
      
      help = new JMenuItem("Help",KeyEvent.VK_H);
      help.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_2, ActionEvent.ALT_MASK));
      help.getAccessibleContext().setAccessibleDescription("Viser hjelp box");
      hjelp.add(help);
      help.addActionListener(this);
      
      about = new JMenuItem("About",KeyEvent.VK_A);
      about.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_3, ActionEvent.ALT_MASK));
      about.getAccessibleContext().setAccessibleDescription("Viser about box");
      hjelp.add(about);
      about.addActionListener(this);
      
      exit = new JMenuItem("Exit",KeyEvent.VK_E);
      exit.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_1, ActionEvent.ALT_MASK));
      exit.getAccessibleContext().setAccessibleDescription("Viser about box");
      fil.add(exit);
      exit.addActionListener(this);
      
      //Klargjr container
      c = getContentPane();
      c.setLayout(null);
      
      //Setter opp glCanvaset
      canv = new BildeBokCanvas(this, 800,540);
      canv.setBounds(0,60,800,540);
      c.add(canv);
      
      infoPanel = new JPanel(null);
      infoPanel.setBackground(new Color(229,242,255));
      infoPanel.setBounds(0,0,800,60);
      c.add(infoPanel);
      
      infoLabel = new JLabel(heading);
      infoLabel.setFont(new Font("Arial", Font.BOLD, 24));
      infoLabel.setBounds(5,5,450, 40);
      infoPanel.add(infoLabel);
      
      
      anim = new JButton("Open Book");
      anim.setBounds(460, 5, 120, 25);
      anim.addActionListener(this);
      infoPanel.add(anim);
      
      turn = new JButton("Turn Page");
      turn.setBounds(590, 5, 120, 25);
      turn.addActionListener(this);
      turn.setEnabled(false);
      infoPanel.add(turn);
      
      canv.addMouseListener( mHandler );
      canv.addMouseMotionListener( mHandler );
      
      
   }
   
   /**
    * De pflgende 4 metoder returnerer de x og z rotasjonene.
    * Koden som tar seg av rotering av boken gjennom musen, er
    * meget inspirert av Brre Stenseth sin tilsvarende kode.
    */
   
   public float getRotX(){
      return this.rotx;
   }
   public float getRotZ(){
      return this.rotz;
   }
   public float getLastX(){
      return this.lastx;
   }
   public float getLastZ(){
      return this.lastz;
   }
   
   public boolean mIsMoving(){
      return this.m_is_moving;
   }
   
   
   /**
    * debug
    * @param s Stringen som skal skrives ut
    *
    * Dette er den standarde debug metoden.
    */
   private void debug(String s){
      if(debugOn){
	 System.out.println(this.getClass().getName() + " : " + s);
      }
   }
   
   
   /**
    * enableTurn
    * @param enable Verdien som bestemmer om TurnPage knappen skal vre enablet
    */
   public void enableTurn(boolean enable){
      turn.setEnabled(enable);
   }
   
   /**
    * enableAnim
    * @param enable Verdien som bestemmer om OpenBook knappen skal vre enablet
    */
   public void enableAnim(boolean enable){
      anim.setEnabled(enable);
   }
   
   /**
    * actionPerformed
    * @param e ActionEvent som forteller om hva som har skjedd
    *
    * Denne metoden registrerer hvilken knapp som har blitt trykket p
    * og hvilke flger det skal f.
    */
   public void actionPerformed(ActionEvent e){
      String ac = e.getActionCommand();
      if(ac.equals("Open Book")){
	 canv.setOpen(true);
	 t = new Thread(canv);
         t.start();
      }else if(ac.equals("Turn Page")){
	 antPress ++;
	 if(antPress <= 6){
	    canv.setOpen(false);
	    t2 = new Thread(canv);
	    t2.start();
	 }else{
	    enableTurn(false);
	 }
	 
      }else if(ac.equals("Exit")){
	 exit();
      }else if(ac.equals("About")){
	 showAbout();
      }else if(ac.equals("Help")){
	 showHelp();
      }
   }
   
   /**
    * exit
    * Metode som avslutter programmet
    */
   private void exit(){
      System.exit(0);
   }
   
   /**
    * showAbout
    * Metode som viser aboutBoksen
    */
   private void showAbout(){
      AboutBox ab = new AboutBox("about");
   }
   
   /**
    * showHelp
    * Metode som viser helpBoksen
    */
   private void showHelp(){
      AboutBox ab = new AboutBox("help");
   }
   
   /**
    * @class MouseHandler
    * Klasse som tar seg av mushndtering.
    * Denne indre klassen er hentet fra et av Brre Stenseth sine
    * eksempler
    */
   class MouseHandler implements MouseListener, MouseMotionListener
   {
      public void mouseEntered(MouseEvent e) {}
      public void mouseExited(MouseEvent e) {}
      public void mouseMoved(MouseEvent e) {}
      public void mouseClicked(MouseEvent e) {}
      public void mouseReleased(MouseEvent e)
      {
	 // object is not moving anymore
	 m_is_moving=false;
	 canv.repaint();
      }
      public void mousePressed(MouseEvent e)
      {
	 if(!e.isShiftDown())
	    {
	       lastx = e.getX();
	       lastz = e.getY();
	       m_is_moving=true;
	    }
      }
      public void mouseDragged(MouseEvent e)
      {
	 if(!m_is_moving)
	    return;
	 int x = e.getX();
	 int y = e.getY();
	 Dimension dim = e.getComponent().getSize();
	 int width = dim.width;
	 int height = dim.height;
	 
	 rotz += (90.0f*((float)(x-lastx)/(float)(width)));
	 rotx += (90.0f*((float)(y-lastz)/(float)(height)));
	 
	 lastx = x;
	 lastz = y;
	 
	 // repaint with moving flag set
	 canv.repaint();
      }
   }
}

