//gl4java imports
import gl4java.GLFunc;
import gl4java.awt.GLCanvas;

/**
 * <strong>Program:</strong>      BildeBok<br>
 * <strong>File:</strong>         FargeGen.java<br>
 * <strong>Description:</strong>  openGL - klasse som setter farge i et canvas<br>
 * <strong>Author:</strong>       Kenneth Stigen - kenneths@frodo.hiof.no<br>
 * <strong>Environment:</strong>  Windows - gl4java<br>
 * <strong>Notes:</strong>        Dette er en del av prosjektet i grafisk databehandling V2002<br>
 *               Denne metoden inneholder mange flere farger enn dem som er brukt<br>
 *               i prosjektet. Grunnen til dette er at den samme klassen er brukt<br>
 *               i flere andre applikasjoner, og jeg har ikke fjernet de resterende<br>
 *               metodene<br>
 *
 * @author Kenneth Stigen (mailto: kenneths@frodo.hiof.no, web: http://frodo.hiof.no/~kenneths)
 * @version Version 1.0
 */
public class FargeGen{
   
   //PRIVATE VARIABLES
   private GLFunc gl;
   private GLCanvas myParent;
   
   /**
    * Constructor
    * @param param GLCanvas som er "far" til dette objektet.
    *
    * Denne metoden setter myParent til glcanvaset som fargene
    * skal settes til.
    * Lager ogs sin egen gl variabel
    */
   public FargeGen(GLCanvas parent){
      myParent = parent;
      this.gl = myParent.gl;
   }
   
   /**
    * setRedMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setRedMaterial(){
      float amb[]={1.0f,0.29f,0.29f,1.0f};
      float diff[]={0.0f,0.0f,0.0f,1.0f};
      float spec[]={1.0f,1.0f,1.0f,1.0f};
      float shine=128f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setGreenMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setGreenMaterial(){
      float amb[]={0.0f,1.0f,0.0f,1.0f};
      float diff[]={0.0f,0.0f,0.0f,1.0f};
      float spec[]={0.0f,0.0f,0.0f,1.0f};
      float shine=0f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setBlueMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setBlueMaterial(){
      float amb[]={0.0f,0.0f,1.0f,1.0f};
      float diff[]={0.0f,1.0f,0.0f,1.0f};
      float spec[]={0.0f,0.0f,0.0f,1.0f};
      float shine=128f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setLightBlueMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setLightBlueMaterial(){
      float amb[]={0.46f,0.46f,0.96f,1.0f};
      float diff[]={0.52f,0.52f,0.52f,1.0f};
      float spec[]={0.633f,0.727811f,0.633f,1.0f};
      float shine=128f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setGreyMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setGreyMaterial(){
      float amb[]={0.7f,0.7f,0.7f,1.0f};
      float diff[]={0.2f,0.2f,0.2f,1.0f};
      float spec[]={0.2f,0.2f,0.2f,1.0f};
      float shine=22f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setBlackMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setBlackMaterial(){
      float amb[]={0.0f,0.0f,0.0f,1.0f};
      float diff[]={0.0f,0.0f,0.0f,1.0f};
      float spec[]={1.0f,1.0f,1.0f,1.0f};
      float shine=128f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setBrownMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setBrownMaterial(){
      float amb[]={1.0f,0.82f,0.69f,1.0f};
      float diff[]={0.1f,0.1f,0.1f,1.0f};
      float spec[]={0.21f,0.21f,0.21f,1.0f};
      float shine=14f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setGoldMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setGoldMaterial(){
      float amb[]={1.0f,0.73f,0.0f,1.0f};
      float diff[]={0.1f,0.1f,0.1f,1.0f};
      float spec[]={0.21f,0.21f,0.21f,1.0f};
      float shine=14f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setEmeraldMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setEmeraldMaterial(){
      float amb[]={0.0215f,0.1745f,0.0215f,1.0f};
      float diff[]={0.07568f,0.61424f,0.07568f,1.0f};
      float spec[]={0.633f,0.727811f,0.633f,1.0f};
      float shine=76.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setJadeMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setJadeMaterial(){
      float amb[]={0.135f,0.2225f,0.1575f,1.0f};
      float diff[]={0.54f,0.89f,0.63f,1.0f};
      float spec[]={0.316228f,0.316228f,0.316228f,1.0f};
      float shine=12.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setPearlMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setPearlMaterial(){
      float amb[]={0.25f,0.20725f,0.20725f,1.0f};
      float diff[]={1.0f,0.829f,0.829f,1.0f};
      float spec[]={0.296648f,0.296648f,0.296648f,1.0f};
      float shine=11.264f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setRubyMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setRubyMaterial(){
      float amb[]={0.1745f,0.01175f,0.01175f,1.0f};
      float diff[]={0.61424f,0.04136f,0.04136f,1.0f};
      float spec[]={0.727811f,0.626959f,0.626959f,1.0f};
      float shine=76.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setTurquoiseMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setTurquoiseMaterial(){
      float amb[]={0.1f,0.18725f,0.1745f,1.0f};
      float diff[]={0.396f,0.74151f,0.69102f,1.0f};
      float spec[]={0.297254f,0.30829f,0.306678f,1.0f};
      float shine=12.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setBrassMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setBrassMaterial(){
      float amb[]={0.329412f,0.223529f,0.027451f,1.0f};
      float diff[]={0.780392f,0.568627f,0.113725f,1.0f};
      float spec[]={0.992157f,0.941176f,0.807843f,1.0f};
      float shine=27.8974f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setBronzeMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setBronzeMaterial(){
      float amb[]={0.2125f,0.1275f,0.054f,1.0f};
      float diff[]={0.714f,0.4284f,0.18144f,1.0f};
      float spec[]={0.393548f,0.271906f,0.166721f,1.0f};
      float shine=25.6f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setChromeMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setChromeMaterial(){
      float amb[]={0.25f,0.25f,0.25f,1.0f};
      float diff[]={0.4f,0.4f,0.4f,1.0f};
      float spec[]={0.774597f,0.774597f,0.774597f,1.0f};
      float shine=76.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setCopperMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setCopperMaterial(){
      float amb[]={0.19125f,0.0735f,0.0225f,1.0f};
      float diff[]={0.7038f,0.27048f,0.0828f,1.0f};
      float spec[]={0.256777f,0.137622f,0.086014f,1.0f};
      float shine=12.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setSilverMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setSilverMaterial(){
      float amb[]={0.19225f,0.19225f,0.19225f,1.0f};
      float diff[]={0.50754f,0.50754f,0.50754f,1.0f};
      float spec[]={0.508273f,0.508273f,0.508273f,1.0f};
      float shine=51.2f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setWarmWhiteMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setWarmWhiteMaterial(){
      float amb[]={0.3f,0.2f,0.2f,1.0f};
      float diff[]={1.0f,0.9f,0.8f,1.0f};
      float spec[]={0.4f,0.2f,0.2f,1.0f};
      float shine=44.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
   
   /**
    * setWhiteMaterial
    *
    * Metode som setter fargen som metodenavnet tilsier
    */
   public void setWhiteMaterial(){
      float amb[]={1.0f,1.0f,1.0f,1.0f};
      float diff[]={1.0f,1.0f,1.0f,1.0f};
      float spec[]={0.47f,0.47f,0.47f,1.0f};
      float shine=44.8f;
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_AMBIENT,amb);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_DIFFUSE,diff);
      gl.glMaterialfv(myParent.GL_FRONT_AND_BACK,myParent.GL_SPECULAR,spec);
      gl.glMaterialf(myParent.GL_FRONT_AND_BACK,myParent.GL_SHININESS,shine);
   }
}

