/**
 * <strong>Program:</strong>      BildeBok<br>
 * <strong>File:</strong>         PagePainter.java<br>
 * <strong>Description:</strong>  Klasse som holder rede p alle punkter til innholdet i boken<br>
 * <strong>Author:</strong>       Kenneth Stigen - kenneths@frodo.hiof.no<br>
 * <strong>Environment:</strong>  Windows - jdk 1.3.1<br>
 * <strong>Notes:</strong>        Dette er en del av prosjektet i grafisk databehandling V2002<br>
 *<br>
 *               Logikken i oppbyggingen av a,b,c,d 1-4 verdiene er som flger<br>
 *<br>
 *					  Dette er boken sett undenfra nr den er upnet. Illustrasjonen<br>
 *               skal vise hva de forskjellige kontrollpunktene er.<br>
 *<br>
 *                  4         3         2         1<br>
 *               d  *******************************<br>
 *                  4         3         2         1<br>
 *               c  *******************************<br>
 *                  4         3         2         1<br>
 *               b  *******************************<br>
 *		    4         3         2         1<br>
 *               a  *******************************<br>
 *
 *
 * @author Kenneth Stigen (mailto: kenneths@frodo.hiof.no, web: http://frodo.hiof.no/~kenneths)
 * @version Version 1.0
 */
public class PagePainter {
   
   // PRIVATE VARIABLES
   private boolean debugOn = false;
   private String front = "";
   private String back = "";
   private FargeGen myColor;
   private TexturLaster myTextureLoader;
   
   //Faktor for hvor mye tykkelsen p boken skal ke/minske med (tykkelsen p hvert ark)
   private final float decFact = 0.03f;
   
   //Variabler for arrayene som skal holde kontrollpunktene til alt innholdet
   private float botPages[];
   private float topPages[];
   private float rightPages[];
   private float leftPages[];
   private float textPage[];
   private float prevPage[];
   private float nextPage[];
   private float lastPage[];
   
   private float leftBotPages[];
   private float leftTopPages[];
   private float leftLeftPages[];
   private float leftLastPage[];
   
   //Variabel for "ryggen" av innholdet
   private float pageRyggX = 0.5f;
   
   //Variabler for den "aktive" siden
   private float txt1X;
   private float txt1Z;
   private float txt2X;
   private float txt2Z;
   private float txt3X;
   private float txt3Z;
   private float txt4X;
   private float txt4Z;
   
   //Variabler for den neste siden
   private float next1X;
   private float next1Z;
   private float next2X;
   private float next2Z;
   private float next3X;
   private float next3Z;
   private float next4X;
   private float next4Z;
   
   //Variabler for siden som nettopp har blitt bladd
   private float prev1X;
   private float prev1Z;
   private float prev2X;
   private float prev2Z;
   private float prev3X;
   private float prev3Z;
   private float prev4X;
   private float prev4Z;
   
   
   //Variabler for botPages.
   //botPages er nedre del av innholdet (flaten som er lengst nede p y-aksen)
   private float a1x = 0.0f;		private float a1z = 0.0f;
   private float b1x = 0.0f;		private float b1z = 0.1f;
   private float c1x = 0.0f;		private float c1z = 0.3f;
   private float d1x = 0.0f;		private float d1z = 0.45f;
   
   private float a2x = 1.15f;		private float a2z = 0.0f;
   private float b2x = 1.15f;		private float b2z = 0.1f;
   private float c2x = 1.15f;		private float c2z = 0.3f;
   private float d2x = 1.15f;		private float d2z = 0.45f;
   
   private float a3x = 2.3f;		private float a3z = 0.0f;
   private float b3x = 2.3f;		private float b3z = 0.1f;
   private float c3x = 2.3f;		private float c3z = 0.3f;
   private float d3x = 2.3f;		private float d3z = 0.45f;
   
   private float a4x = 3.4f;		private float a4z = 0.0f;
   private float b4x = 3.4f;		private float b4z = 0.1f;
   private float c4x = 3.4f;		private float c4z = 0.3f;
   private float d4x = 3.4f;		private float d4z = 0.45f;
   
   //Variabler for venstre del av boken
   private float lefta1x = 0.0f;		private float lefta1z = 0.0f;
   private float leftb1x = 0.0f;		private float leftb1z = 0.1f;
   private float leftc1x = 0.0f;		private float leftc1z = 0.3f;
   private float leftd1x = 0.0f;		private float leftd1z = 0.45f;
   
   private float lefta2x = -1.15f;		private float lefta2z = 0.0f;
   private float leftb2x = -1.15f;		private float leftb2z = 0.1f;
   private float leftc2x = -1.15f;		private float leftc2z = 0.3f;
   private float leftd2x = -1.15f;		private float leftd2z = 0.45f;
   
   private float lefta3x = -2.3f;		private float lefta3z = 0.0f;
   private float leftb3x = -2.3f;		private float leftb3z = 0.1f;
   private float leftc3x = -2.3f;		private float leftc3z = 0.3f;
   private float leftd3x = -2.3f;		private float leftd3z = 0.45f;
   
   private float lefta4x = -3.4f;		private float lefta4z = 0.0f;
   private float leftb4x = -3.4f;		private float leftb4z = 0.1f;
   private float leftc4x = -3.4f;		private float leftc4z = 0.3f;
   private float leftd4x = -3.4f;		private float leftd4z = 0.45f;
   
   //Kontrollpunkter for teksturer
   //Disse spesifiserer at teksturen skal dekke hele flaten
   float txpts[] = {
      -1.0f, 0.0f,    0.0f, 0.0f,
      -1.0f, -1.0f,   0.0f, -1.0f
   };
   
   
   /**
    * Constructor
    *
    * Kaller p metoden initArr, som initialiserer/oppdaterer alle arrayer
    */
   public PagePainter(){
      initArr();
   }
   
   /**
    * update
    *
    * Metode som kaller p metoden initArr, som oppdaterer alle arrayer.
    */
   public void update(){
      initArr();
   }
   
   /**
    * getTxpts
    * @return txpts Returnerer arrayen med kontrollpunkter for teksturer
    */
   public float[] getTxpts(){
      return this.txpts;
   }
   
   /**
    * makeNext
    *
    * Metode som gjr klar neste side for visning.
    * next-kontrollpunktene blir satt til d-verdiene
    * som allerede er manipulert til  vre "lavere" satt.
    */
   public void makeNext(){
      next1X = d1x;
      next1Z = d1z;
      next2X = d2x;
      next2Z = d2z;
      next3X = d3x;
      next3Z = d3z;
      next4X = d4x;
      next4Z = d4z;
      initArr();
      
   }
   
   /**
    * decreaseEdge
    *
    * Metode som senker innholdet av hyre side av boken.
    * Jeg har definert variabelen decFact til  vre "tykkelsen" til et ark.
    * For forklaring av punktene: se toppen.
    * Metoden kaller til slutt p initArr() som oppdaterer arrayene
    *
    */
   public void decreaseEdge(){
      d1x += decFact;
      d2z -= decFact;
      d3z -= decFact;
      d4x += decFact;
      d4z -= decFact;
      
      if(d1x >= c1x)c1x += decFact;
      if(d1x >= b1x)b1x += decFact;
      if(d1x >= d2x)d2x += decFact;
      
      
      if(d4z <= c4z)c4z -= decFact;
      if(d4z <= b4z)b4z -= decFact;
      if(d4z <= a4z)a4z -= decFact;
      
      
      if(d3z <= c3z)c3z -= decFact;
      if(d3z <= b3z)b3z -= decFact;
      if(d3z <= a3z)a3z -= decFact;
      
      if(d2z <= c2z)c2z -= decFact;
      if(d2z <= b2z)b2z -= decFact;
      if(d2z <= a2z)a2z -= decFact;
      
      
      if(d4x >= c4x)c4x += decFact;
      if(d4x >= b4x)b4x += decFact;
      if(d4x >= a4x)a4x += decFact;
      
      initArr();
   }
   
   /**
    * initLeftEdge
    *
    * Metode som initierer hvor frste arket i boken skal ligge.
    * Denne metoden blir kalt etter at frste ark i boken er bladd.
    * Dette danner grunnlaget for tykkelsen p venstre side.
    * left-variablene er variablene for tykkelsen
    * prev-variablene er variablene for hvor siden landet.
    */
   public void initLeftEdge(){
      lefta1z = prev1Z;		lefta1x = prev1X;
      leftb1z = prev1Z;		leftb1x = prev1X;
      leftc1z = prev1Z;		leftc1x = prev1X;
      leftd1z = prev1Z;		leftd1x = prev1X;
      
      lefta2z = prev2Z;		lefta2x = prev2X;
      leftb2z = prev2Z;		leftb2x = prev2X;
      leftc2z = prev2Z;		leftc2x = prev2X;
      leftd2z = prev2Z;		leftd2x = prev2X;
      
      lefta3z = prev3Z;		lefta3x = prev3X;
      leftb3z = prev3Z;		leftb3x = prev3X;
      leftc3z = prev3Z;		leftc3x = prev3X;
      leftd3z = prev3Z;		leftd3x = prev3X;
      
      lefta4z = prev4Z;		lefta4x = prev4X;
      leftb4z = prev4Z;		leftb4x = prev4X;
      leftc4z = prev4Z;		leftc4x = prev4X;
      leftd4z = prev4Z;		leftd4x = prev4X;
      initArr();
   }
   
   /**
    * increadeLeftEdge()
    *
    * Metode som ker tykkelsen p venstre side av boken
    */
   public void increaseLeftEdge(){
      leftd2z += decFact;
      leftd3z += decFact;
      leftd4z += decFact;
      leftd4x += decFact;
      leftd1x += decFact;
      leftd2x += decFact*3.5;
      leftc2x += decFact*3.5;
      leftb2x += decFact*2.5;
      lefta2x += decFact*2.5;
      
      //Forandre de nedre verdiene p grunn av vekten til alle sidene...
      lefta2z -= decFact/2;
      lefta3z -= decFact/2;
      
      initArr();
   }
   
   /**
    * rotatePages
    *
    * Metode som setter tilbake, textPage slik at den er klar til  blas igjen
    * Den setter ogs prevPage til  vre slik som textPage var etter at den var
    * bladd. "Roterer" sidene.
    */
   public void rotatePages(){
      prev1X = txt1X;
      prev1Z = txt1Z;
      prev2X = txt2X;
      prev2Z = txt2Z;
      prev3X = txt3X;
      prev3Z = txt3Z;
      prev4X = txt4X;
      prev4Z = txt4Z;
      
      txt1X = next1X;
      txt1Z = next1Z;
      txt2X = next2X;
      txt2Z = next2Z;
      txt3X = next3X;
      txt3Z = next3Z;
      txt4X = next4X;
      txt4Z = next4Z;
      initArr();
      
   }
   
   /**
    * addTurningValues
    * @param xOuter Den nye verdien til den ytre x-verdien av siden som blas
    * @param zOuter Den nye verdien til den ytre z-verdien av siden som blas
    * @param xMidOut Den nye verdien til den ytterste midtre x-verdien av siden som blas
    * @param zMidOut Den nye verdien til den ytterste midtre z-verdien av siden som blas
    * @param xMidInn Den nye verdien til den innerste midtre x-verdien av siden som blas
    * @param zMidInn Den nye verdien til den innerste midtre z-verdien av siden som blas
    *
    * Metoden oppdaterer kontrollpunktene til siden som blas.
    * Kaller til slutt p initArr for  sette disse til arrayen.
    */
   public void addTurningValues(float xOuter, float zOuter, float xMidOut, float zMidOut, float xMidInn, float zMidInn){
      this.txt4X = xOuter;
      this.txt4Z = zOuter;
      this.txt3X = xMidOut;
      this.txt3Z = zMidOut;
      this.txt2X = xMidInn;
      this.txt2Z = zMidInn;
      initArr();
   }
   
   /**
    * addXValues
    * @param first Hvor mye x-verdiene p d-linjen skal forskyve seg
    * @param sec Hvor mye x-verdiene p c-linjen skal forskyve seg
    * @param third Hvor mye x-verdiene p b-linjen skal forskyve seg
    * @param fourth Hvor mye x-verdiene p a-linjen skal forskyve seg
    *
    * Denne metoden benyttes nr boken pnes.
    * Grunnen til at noen av variablene forandres med en faktor, og noen
    * forandres med  legge til en verdi, er for  f byen p innholdet
    * nr permen ligger flat.
    */
   public void addXValues(float first, float sec, float third, float fourth){
      d2x += first*3.1;
      c2x += sec*3.1;
      b2x += third*3.5;
      a2x += fourth*3.5;
      a2x -= 0.01f;
      
      d2z += 0.005f;
      c2z += 0.005f;
      b2z += 0.007f;
      a2z += 0.003f;
      
      
      d3z += 0.001f;
      c3z += 0.001f;
      b3z += 0.001f;
      a3z += 0.001f;
      
      
      
      d3x += first;
      c3x += sec;
      b3x += third;
      a3x += fourth;
      
      d4x += first;
      c4x += sec;
      b4x += third;
      a4x += fourth;
   }
   
   /**
    * updateTextPage
    *
    * Metode som kalles etter at boken er pnet for  sette p plass
    * frste side.
    */
   public void updateTextPage(){
      txt1X = d1x;
      txt1Z = d1z;
      txt2X = d2x;
      txt2Z = d2z;
      txt3X = d3x;
      txt3Z = d3z;
      txt4X = d4x;
      txt4Z = d4z;
   }
   
   /**
    * setBotPages
    * @param a1x
    * @param b1x
    * @param c1x
    * @param d1x
    * @param a1z
    * @param b1z
    * @param c1z
    * @param d1z
    *
    * Metode som brukes nr boken pnes.
    * Denne metoden setter verdiene til den nedre delen av innholdet p hyre side
    * Verdiene blir kalkulert i metoden openBook i klassen BildeBokCanvas
    */
   public void setBotPages(float a1x, float b1x, float c1x, float d1x, float a1z, float b1z, float c1z, float d1z){
      this.a1x = a1x;
      this.b1x = b1x;
      this.c1x = c1x;
      this.d1x = d1x;
      
      this.a1z = a1z;
      this.b1z = b1z;
      this.c1z = c1z;
      this.d1z = d1z;
      
      initArr();
   }
   
   /**
    * addRyggPage
    * @param xValue Verdien av innholdsryggen som forandres
    *
    * Denne metoden brukes ogs nr boken pnes
    * Denne ker x-verdiene til innholdets rygg. Grunnen til
    * dette er at nr boken pnes roteres ryggen, og ville ha blitt
    * gjemt inne i selve ryggen p permen. For  unng dette "lfter"
    * vi den litt opp, slik at den ser ut som om den str p samme sted
    * som den gjorde fr vi pnet boken.
    */
   public void addRyggPage(float xValue){
      this.pageRyggX += xValue;
   }
   
   
   /**
    * initArr
    *
    * Metode som initialiserer/oppdaterer alle kontrollpunktarrayer for innholdet av boken.
    * Alle variablene blir definert og forandret gjennom de ovenstende metodene.
    */
   private void initArr(){
      
      float tmpLeftBotPages[] = {
	 leftd1x, -2.0f, leftd1z,		leftd2x, -2.0f, leftd2z,		leftd3x, -2.0f, leftd3z,		leftd4x, -2.0f, leftd4z,	//d
	 leftc1x, -2.0f, leftc1z,		leftc2x, -2.0f, leftc2z,		leftc3x, -2.0f, leftc3z,		leftc4x, -2.0f, leftc4z,	//c
	 leftb1x, -2.0f, leftb1z,		leftb2x, -2.0f, leftb2z,		leftb3x, -2.0f, leftb3z,		leftb4x, -2.0f, leftb4z,	//b
	 lefta1x, -2.0f, lefta1z,		lefta2x, -2.0f, lefta2z,		lefta3x, -2.0f, lefta3z,		lefta4x, -2.0f, lefta4z, 	//a
      };
      
      float tmpLeftTopPages[] = {
	 leftd1x, 2.0f, leftd1z,		leftd2x, 2.0f, leftd2z,		leftd3x, 2.0f, leftd3z,		leftd4x, 2.0f, leftd4z,	//d
	 leftc1x, 2.0f, leftc1z,		leftc2x, 2.0f, leftc2z,		leftc3x, 2.0f, leftc3z,		leftc4x, 2.0f, leftc4z,	//c
	 leftb1x, 2.0f, leftb1z,		leftb2x, 2.0f, leftb2z,		leftb3x, 2.0f, leftb3z,		leftb4x, 2.0f, leftb4z,	//b
	 lefta1x, 2.0f, lefta1z,		lefta2x, 2.0f, lefta2z,		lefta3x, 2.0f, lefta3z,		lefta4x, 2.0f, lefta4z, 	//a
      };
      
      float tmpLeftLeftPages[] = {
	 lefta4x, -2.0f, lefta4z,		lefta4x, -1.0f, lefta4z,	lefta4x, 1.0f, lefta4z,	lefta4x, 2.0f, lefta4z,
	 leftb4x, -2.0f, leftb4z,		leftb4x, -1.0f, leftb4z,	leftb4x, 1.0f, leftb4z,	leftb4x, 2.0f, leftb4z,
	 leftc4x, -2.0f, leftc4z,		leftc4x, -1.0f, leftc4z,	leftc4x, 1.0f, leftc4z,	leftc4x, 2.0f, leftc4z,
	 leftd4x, -2.0f, leftd4z,		leftd4x, -1.0f, leftd4z,	leftd4x, 1.0f, leftd4z,	leftd4x, 2.0f, leftd4z,
      };
      
      float tmpLeftLastPage[] = {
	 lefta1x, 2.0f, lefta1z,		lefta2x, 2.0f, lefta2z,		lefta3x, 2.0f, lefta3z,		lefta4x, 2.0f, lefta4z,	//d
	 lefta1x, 1.0f, lefta1z,		lefta2x, 1.0f, lefta2z,		lefta3x, 1.0f, lefta3z,		lefta4x, 1.0f, lefta4z,	//c
	 lefta1x, -1.0f, lefta1z,		lefta2x, -1.0f, lefta2z,		lefta3x, -1.0f, lefta3z,		lefta4x, -1.0f, lefta4z,	//b
	 lefta1x, -2.0f, lefta1z,		lefta2x, -2.0f, lefta2z,		lefta3x, -2.0f, lefta3z,		lefta4x, -2.0f, lefta4z, 	//a
      };
      
      float tmpBotPages[] = {
	 d1x, -2.0f, d1z,		d2x, -2.0f, d2z,		d3x, -2.0f, d3z,		d4x, -2.0f, d4z,	//d
	 c1x, -2.0f, c1z,		c2x, -2.0f, c2z,		c3x, -2.0f, c3z,		c4x, -2.0f, c4z,	//c
	 b1x, -2.0f, b1z,		b2x, -2.0f, b2z,		b3x, -2.0f, b3z,		b4x, -2.0f, b4z,	//b
	 a1x, -2.0f, a1z,		a2x, -2.0f, a2z,		a3x, -2.0f, a3z,		a4x, -2.0f, a4z, 	//a
	 
      };
      
      float tmpTopPages[] = {
	 d1x, 2.0f, d1z,		d2x, 2.0f, d2z,		d3x, 2.0f, d3z,		d4x, 2.0f, d4z,	//d
	 c1x, 2.0f, c1z,		c2x, 2.0f, c2z,		c3x, 2.0f, c3z,		c4x, 2.0f, c4z,	//c
	 b1x, 2.0f, b1z,		b2x, 2.0f, b2z,		b3x, 2.0f, b3z,		b4x, 2.0f, b4z,	//b
	 a1x, 2.0f, a1z,		a2x, 2.0f, a2z,		a3x, 2.0f, a3z,		a4x, 2.0f, a4z, 	//a
	 
      };
      
      
      float tmpRightPages[] = {
	 a4x, -2.0f, a4z,		a4x, -1.0f, a4z,	a4x, 1.0f, a4z,	a4x, 2.0f, a4z,
	 b4x, -2.0f, b4z,		b4x, -1.0f, b4z,	b4x, 1.0f, b4z,	b4x, 2.0f, b4z,
	 c4x, -2.0f, c4z,		c4x, -1.0f, c4z,	c4x, 1.0f, c4z,	c4x, 2.0f, c4z,
	 d4x, -2.0f, d4z,		d4x, -1.0f, d4z,	d4x, 1.0f, d4z,	d4x, 2.0f, d4z,
      };
      
      float tmpLeftPages[] = {
	 pageRyggX, -2.0f, 0.0f,		pageRyggX, 2.0f, 0.0f,
	 pageRyggX, -2.0f, 0.1f,		pageRyggX, 2.0f, 0.1f,
	 pageRyggX, -2.0f, 0.3f,		pageRyggX, 2.0f, 0.3f,
	 pageRyggX, -2.0f, 0.45f,		pageRyggX, 2.0f, 0.45f,
	 
      };
      
      float tmpTextPage[] = {
	 
	 txt1X, 2.0f, txt1Z, txt2X, 2.0f, txt2Z, txt3X, 2.0f, txt3Z, txt4X, 2.0f, txt4Z,
	 txt1X, 1.0f, txt1Z, txt2X, 1.0f, txt2Z, txt3X, 1.0f, txt3Z, txt4X, 1.0f, txt4Z,
	 txt1X,-1.0f, txt1Z, txt2X, -1.0f, txt2Z, txt3X, -1.0f, txt3Z, txt4X, -1.0f, txt4Z,
	 txt1X,-2.0f, txt1Z, txt2X, -2.0f, txt2Z, txt3X, -2.0f, txt3Z, txt4X, -2.0f, txt4Z,
	 
	 
	 
      };
      
      float tmpPrevPage[] = {
	 prev1X, 2.0f, prev1Z, prev2X, 2.0f, prev2Z, prev3X, 2.0f, prev3Z, prev4X, 2.0f, prev4Z,
	 prev1X, 1.0f, prev1Z, prev2X, 1.0f, prev2Z, prev3X, 1.0f, prev3Z, prev4X, 1.0f, prev4Z,
	 prev1X,-1.0f, prev1Z, prev2X, -1.0f, prev2Z, prev3X, -1.0f, prev3Z, prev4X, -1.0f, prev4Z,
	 prev1X,-2.0f, prev1Z, prev2X, -2.0f, prev2Z, prev3X, -2.0f, prev3Z, prev4X, -2.0f, prev4Z,
      };
      
      float tmpNextPage[] = {
	 next1X, 2.0f, next1Z, next2X, 2.0f, next2Z, next3X, 2.0f, next3Z, next4X, 2.0f, next4Z,
	 next1X, 1.0f, next1Z, next2X, 1.0f, next2Z, next3X, 1.0f, next3Z, next4X, 1.0f, next4Z,
	 next1X,-1.0f, next1Z, next2X, -1.0f, next2Z, next3X, -1.0f, next3Z, next4X, -1.0f, next4Z,
	 next1X,-2.0f, next1Z, next2X, -2.0f, next2Z, next3X, -2.0f, next3Z, next4X, -2.0f, next4Z,
      };
      
      float tmpLastPage[] = {
	 a1x, 2.0f, a1z,		a2x, 2.0f, a2z,		a3x, 2.0f, a3z,		a4x, 2.0f, a4z,	//d
	 a1x, 1.0f, a1z,		a2x, 1.0f, a2z,		a3x, 1.0f, a3z,		a4x, 1.0f, a4z,	//c
	 a1x, -1.0f, a1z,		a2x, -1.0f, a2z,		a3x, -1.0f, a3z,		a4x, -1.0f, a4z,	//b
	 a1x, -2.0f, a1z,		a2x, -2.0f, a2z,		a3x, -2.0f, a3z,		a4x, -2.0f, a4z, 	//a
      };
      
      
      
      botPages = tmpBotPages;
      topPages = tmpTopPages;
      rightPages = tmpRightPages;
      leftPages = tmpLeftPages;
      textPage = tmpTextPage;
      prevPage = tmpPrevPage;
      nextPage = tmpNextPage;
      lastPage = tmpLastPage;
      
      leftTopPages = tmpLeftTopPages;
      leftBotPages = tmpLeftBotPages;
      leftLeftPages = tmpLeftLeftPages;
      leftLastPage = tmpLeftLastPage;
      

      
   }

   /**
    * Nedenfor flger divers getmetoder.
    * Jeg ser ikke behovet for  kommentere alle disse
    * De fleste av disse returnerer en array med kontrollpunkter
    * eller et enkelt kontrollpunkt
    */
   
   public float[] getLeftTopPages(){
      return this.leftTopPages;
   }
   public float[] getLeftBotPages(){
      return this.leftBotPages;
   }
   public float[] getLeftLeftPages(){
      return this.leftLeftPages;
   }
   public float[] getLeftLastPage(){
      return this.leftLastPage;
   }
   
   public float[] getBotPages(){
      return this.botPages;
   }
   
   public float[] getTopPages(){
      return this.topPages;
   }
   
   public float[] getRightPages(){
      return this.rightPages;
   }
   
   public float[] getLeftPages(){
      return this.leftPages;
   }
   
   public float[] getTextPage(){
      return this.textPage;
   }
   
   public float[] getLastPage(){
      return this.lastPage;
   }
   
   public float[] getPrevPage(){
      return this.prevPage;
   }
   
   public float[] getNextPage(){
      return this.nextPage;
   }
   
   public float getMidInnZ(){
      return this.txt2Z;
   }
   
   public float getMidOutZ(){
      return this.txt3Z;
   }
   
   public float getOutZ(){
      return this.txt4Z;
   }
   
   public float getMidOutX(){
      return this.txt3X;
   }
   
   public float getMidInnX(){
      return this.txt2X;
   }
   
   public float getOutX(){
      return this.txt4X;
   }
   
   public float getLeftd4z(){
      return this.leftd4z;
   }
   
   public float getLeftd4x(){
      return this.leftd4x;
   };
   
   public float getLeftd3z(){
      return this.leftd3z;
   }
   
   public float getLeftd3x(){
      return this.leftd3x;
   };
   
   public float getLeftd2z(){
      return this.leftd2z;
   }
   
   public float getLeftd2x(){
      return this.leftd2x;
   };
   
   public float getLefta4z(){
      return this.lefta4z;
   }
   
   
   /**
    * debug
    * @param s Stringen som skal skrives ut
    *
    * Dette er den standarde debug metoden.
    */
   private void debug(String s){
      if(debugOn){
	 System.out.println(this.getClass().getName() + " : " + s);
      }
   }
}

