//gl4java imports
import gl4java.awt.GLCanvas;
import gl4java.utils.textures.*;
import gl4java.*;

/**
 * <strong>Program:</strong>      BildeBok<br>
 * <strong>File:</strong>         TexturLaster.java<br>
 * <strong>Description:</strong>  klasse som laster alle texturene<br>
 * <strong>Author:</strong>       Kenneth Stigen - kenneths@frodo.hiof.no<br>
 * <strong>Environment:</strong>  Windows - gl4java<br>
 * <strong>Notes:</strong>        Dette er en del av prosjektet i grafisk databehandling V2002<br>
 *
 * @author Kenneth Stigen (mailto: kenneths@frodo.hiof.no, web: http://frodo.hiof.no/~kenneths)
 * @version Version 1.0
 */
public class TexturLaster{
   
   //PRIVATE VARIABLES
   private boolean debugOn = false;
   private GLFunc gl;
   private GLUFunc glu;
   private GLCanvas myParent;
   private int[] text;
   
   /**
    * Constructor
    * @param parent Forelderen til dette objektet, som er et GLCanvas
    *
    * Constructoren initialiserer dette objektets egne gl og glu objekter
    * I tillegg initialiserer den myParent objektet.
    */
   public TexturLaster(GLCanvas parent){
      this.gl = parent.gl;
      this.glu = parent.glu;
      myParent = parent;
   }
   
   /**
    * bind
    * @param nr Hvilket bilde i arrayen med bilder som skal vre aktivt n.
    *
    * Metoden binder teksturen p den spesifiserte plassen.
    */
   public void bind(int nr){
      gl.glBindTexture(myParent.GL_TEXTURE_2D, text[nr]);
   }
   
   /**
    * LoadTextures
    * @param files Arrayen med filnavn som skal lastes
    *
    * Metoden laster inn alle texturene i files, og setter
    * standard textur-egenskaper p dem.
    */
   public void LoadTextures(String[] files){
      text = new int[files.length];
      debug("Antall bilder som skal lastes: " + files.length);
      PngTextureLoader texLoader = new PngTextureLoader(gl, glu);
      gl.glGenTextures(files.length, text);
      for(int i = 0; i < files.length; i++){
	 debug("I er n: " + i);
	 texLoader.readTexture(files[i]);
	 if(texLoader.isOk()){
	    gl.glBindTexture(myParent.GL_TEXTURE_2D, text[i]);
	    gl.glTexEnvf(myParent.GL_TEXTURE_ENV,myParent.GL_TEXTURE_ENV_MODE,myParent.GL_MODULATE);
	    gl.glTexParameteri(myParent.GL_TEXTURE_2D, myParent.GL_TEXTURE_MAG_FILTER, myParent.GL_NEAREST);
	    gl.glTexParameteri(myParent.GL_TEXTURE_2D, myParent.GL_TEXTURE_MIN_FILTER, myParent.GL_NEAREST);
	    gl.glTexImage2D(myParent.GL_TEXTURE_2D,
			    0,
			    3,
			    texLoader.getImageWidth(),
			    texLoader.getImageHeight(),
			    0,
			    myParent.GL_RGB,
			    myParent.GL_UNSIGNED_BYTE,
			    texLoader.getTexture()
			    );
	    
	 }
	 
      }
      
   }
   
   /**
    * debug
    * @param s Stringen som skal skrives ut
    *
    * Dette er den standarde debug metoden.
    */
   private void debug(String s){
      if(debugOn){
	 System.out.println(this.getClass().getName() + " : " + s);
      }
   }
}
